@@ -5,6 +5,7 @@
  */
 
 use core::ops::{Deref, DerefMut};
+use core::convert::From;
 
 pub struct Pointer<T> {
     pub ptr: *mut T,
@@ -30,6 +31,30 @@ impl<T> Pointer<T> {
     }
 }
 
+impl<T> From<u64> for Pointer<T> {
+    fn from(item: u64) -> Self {
+        Self { ptr: item as *mut T }
+    }
+}
+
+impl<T> From<u32> for Pointer<T> {
+    fn from(item: u32) -> Self {
+        Self { ptr: item as *mut T }
+    }
+}
+
+impl<T> From<u16> for Pointer<T> {
+    fn from(item: u16) -> Self {
+        Self { ptr: item as *mut T }
+    }
+}
+
+impl<T> From<u8> for Pointer<T> {
+    fn from(item: u8) -> Self {
+        Self { ptr: item as *mut T }
+    }
+}
+
 impl<T> Deref for Pointer<T> {
     type Target = T;
 
